@@ -4,8 +4,6 @@
 srcdir=`dirname $0`
 test -z "$srcdir" && srcdir=.
 
-PKG_NAME="Notification Daemon"
-
 (test -f $srcdir/configure.ac \
   && test -d $srcdir/src) || {
     echo -n "**Error**: Directory "\`$srcdir\'" does not look like the"
@@ -13,10 +11,9 @@ PKG_NAME="Notification Daemon"
     exit 1
 }
 
-
 which gnome-autogen.sh || {
     echo "You need to install gnome-common"
     exit 1
 }
 
-USE_GNOME2_MACROS=1 . gnome-autogen.sh
+. gnome-autogen.sh
